#[non_exhaustive]pub struct InvalidHeaderValueError { /* private fields */ }Expand description
A header value (typically an authentication token) contained bytes that are not valid for an HTTP header.
The inner type is just a string message; there is no actionable
diagnostic state beyond that, so this wrapper does not expose any
accessor beyond Display.
Implementations