#[non_exhaustive]pub struct BlobUploadResponse {
pub account_id: Id,
pub blob_id: Id,
pub content_type: String,
pub size: u64,
pub sha256: Option<String>,
}Expand description
Response body returned by a successful blob upload (RFC 8620 6.1).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.account_id: IdThe account the blob was uploaded to.
blob_id: IdServer-assigned opaque blob identifier.
content_type: StringMedia type of the uploaded blob as determined by the server.
size: u64Size of the uploaded blob in bytes.
sha256: Option<String>SHA-256 hex digest of the uploaded blob as 64 hex characters (uppercase or
lowercase), if the server supports the JMAP-CID draft extension (draft-atwood-jmap-cid).
This field is not defined by RFC 8620. It is present only on servers
that advertise the urn:ietf:params:jmap:cid capability. Servers that
do not implement the extension omit the field.